@@ -1,4 +1,5 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
+
 import json
 
 from typing import Any, Dict, List, Optional
@@ -8,6 +9,7 @@ from timeout_sampler import TimeoutWatch
 
 from ocp_resources.exceptions import ExecOnPodError
 from ocp_resources.node import Node
+
 from ocp_resources.resource import NamespacedResource, MissingRequiredArgumentError
 
 
@@ -18,11 +20,6 @@ class Pod(NamespacedResource):
 
     api_version: str = NamespacedResource.ApiVersion.V1
 
-    class Status(NamespacedResource.Status):
-        CRASH_LOOPBACK_OFF = "CrashLoopBackOff"
-        IMAGE_PULL_BACK_OFF = "ImagePullBackOff"
-        ERR_IMAGE_PULL = "ErrImagePull"
-
     def __init__(
         self,
         active_deadline_seconds: Optional[int] = None,
@@ -68,24 +65,24 @@ class Pod(NamespacedResource):
     ) -> None:
         """
         Args:
-            active_deadline_seconds(int): Optional duration in seconds the pod may be active on the node
+            active_deadline_seconds (int): Optional duration in seconds the pod may be active on the node
               relative to StartTime before the system will actively try to mark
               it failed and kill associated containers. Value must be a positive
               integer.
 
-            affinity(Dict[str, Any]): Affinity is a group of affinity scheduling rules.
+            affinity (Dict[str, Any]): Affinity is a group of affinity scheduling rules.
 
-            automount_service_account_token(bool): AutomountServiceAccountToken indicates whether a service account token
+            automount_service_account_token (bool): AutomountServiceAccountToken indicates whether a service account token
               should be automatically mounted.
 
-            containers(List[Any]): List of containers belonging to the pod. Containers cannot currently
+            containers (List[Any]): List of containers belonging to the pod. Containers cannot currently
               be added or removed. There must be at least one container in a
               Pod. Cannot be updated.
 
-            dns_config(Dict[str, Any]): PodDNSConfig defines the DNS parameters of a pod in addition to those
+            dns_config (Dict[str, Any]): PodDNSConfig defines the DNS parameters of a pod in addition to those
               generated from DNSPolicy.
 
-            dns_policy(str): Set DNS policy for the pod. Defaults to "ClusterFirst". Valid values
+            dns_policy (str): Set DNS policy for the pod. Defaults to "ClusterFirst". Valid values
               are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or
               'None'. DNS parameters given in DNSConfig will be merged with the
               policy selected with DNSPolicy. To have DNS options set along with
@@ -102,29 +99,29 @@ class Pod(NamespacedResource):
               use empty DNS settings. DNS parameters such as nameservers and
               search paths should be defined via DNSConfig.
 
-            enable_service_links(bool): EnableServiceLinks indicates whether information about services should
+            enable_service_links (bool): EnableServiceLinks indicates whether information about services should
               be injected into pod's environment variables, matching the syntax
               of Docker links. Optional: Defaults to true.
 
-            ephemeral_containers(List[Any]): List of ephemeral containers run in this pod. Ephemeral containers may
+            ephemeral_containers (List[Any]): List of ephemeral containers run in this pod. Ephemeral containers may
               be run in an existing pod to perform user-initiated actions such
               as debugging. This list cannot be specified when creating a pod,
               and it cannot be modified by updating the pod spec. In order to
               add an ephemeral container to an existing pod, use the pod's
               ephemeralcontainers subresource.
 
-            host_aliases(List[Any]): HostAliases is an optional list of hosts and IPs that will be injected
+            host_aliases (List[Any]): HostAliases is an optional list of hosts and IPs that will be injected
               into the pod's hosts file if specified.
 
-            host_ipc(bool): Use the host's ipc namespace. Optional: Default to false.
+            host_ipc (bool): Use the host's ipc namespace. Optional: Default to false.
 
-            host_network(bool): Host networking requested for this pod. Use the host's network
+            host_network (bool): Host networking requested for this pod. Use the host's network
               namespace. If this option is set, the ports that will be used must
               be specified. Default to false.
 
-            host_pid(bool): Use the host's pid namespace. Optional: Default to false.
+            host_pid (bool): Use the host's pid namespace. Optional: Default to false.
 
-            host_users(bool): Use the host's user namespace. Optional: Default to true. If set to
+            host_users (bool): Use the host's user namespace. Optional: Default to true. If set to
               true or not present, the pod will be run in the host user
               namespace, useful for when the pod needs a feature only available
               to the host user namespace, such as loading a kernel module with
@@ -135,17 +132,17 @@ class Pod(NamespacedResource):
               field is alpha-level and is only honored by servers that enable
               the UserNamespacesSupport feature.
 
-            hostname(str): Specifies the hostname of the Pod If not specified, the pod's hostname
+            hostname (str): Specifies the hostname of the Pod If not specified, the pod's hostname
               will be set to a system-defined value.
 
-            image_pull_secrets(List[Any]): ImagePullSecrets is an optional list of references to secrets in the
+            image_pull_secrets (List[Any]): ImagePullSecrets is an optional list of references to secrets in the
               same namespace to use for pulling any of the images used by this
               PodSpec. If specified, these secrets will be passed to individual
               puller implementations for them to use. More info:
               https://kubernetes.io/docs/concepts/containers/images#specifying-
               imagepullsecrets-on-a-pod
 
-            init_containers(List[Any]): List of initialization containers belonging to the pod. Init
+            init_containers (List[Any]): List of initialization containers belonging to the pod. Init
               containers are executed in order prior to containers being
               started. If any init container fails, the pod is considered to
               have failed and is handled according to its restartPolicy. The
@@ -161,18 +158,18 @@ class Pod(NamespacedResource):
               https://kubernetes.io/docs/concepts/workloads/pods/init-
               containers/
 
-            node_name(str): NodeName is a request to schedule this pod onto a specific node. If it
+            node_name (str): NodeName is a request to schedule this pod onto a specific node. If it
               is non-empty, the scheduler simply schedules this pod onto that
               node, assuming that it fits resource requirements.
 
-            node_selector(Dict[str, Any]): NodeSelector is a selector which must be true for the pod to fit on a
+            node_selector (Dict[str, Any]): NodeSelector is a selector which must be true for the pod to fit on a
               node. Selector which must match a node's labels for the pod to be
               scheduled on that node. More info:
               https://kubernetes.io/docs/concepts/configuration/assign-pod-node/
 
-            os(Dict[str, Any]): PodOS defines the OS parameters of a pod.
+            os (Dict[str, Any]): PodOS defines the OS parameters of a pod.
 
-            overhead(Dict[str, Any]): Overhead represents the resource overhead associated with running a
+            overhead (Dict[str, Any]): Overhead represents the resource overhead associated with running a
               pod for a given RuntimeClass. This field will be autopopulated at
               admission time by the RuntimeClass admission controller. If the
               RuntimeClass admission controller is enabled, overhead must not be
@@ -184,46 +181,46 @@ class Pod(NamespacedResource):
               More info: https://git.k8s.io/enhancements/keps/sig-node/688-pod-
               overhead/README.md
 
-            preemption_policy(str): PreemptionPolicy is the Policy for preempting pods with lower
+            preemption_policy (str): PreemptionPolicy is the Policy for preempting pods with lower
               priority. One of Never, PreemptLowerPriority. Defaults to
               PreemptLowerPriority if unset.  Possible enum values:  - `"Never"`
               means that pod never preempts other pods with lower priority.  -
               `"PreemptLowerPriority"` means that pod can preempt other pods
               with lower priority.
 
-            priority(int): The priority value. Various system components use this field to find
+            priority (int): The priority value. Various system components use this field to find
               the priority of the pod. When Priority Admission Controller is
               enabled, it prevents users from setting this field. The admission
               controller populates this field from PriorityClassName. The higher
               the value, the higher the priority.
 
-            priority_class_name(str): If specified, indicates the pod's priority. "system-node-critical" and
+            priority_class_name (str): If specified, indicates the pod's priority. "system-node-critical" and
               "system-cluster-critical" are two special keywords which indicate
               the highest priorities with the former being the highest priority.
               Any other name must be defined by creating a PriorityClass object
               with that name. If not specified, the pod priority will be default
               or zero if there is no default.
 
-            readiness_gates(List[Any]): If specified, all readiness gates will be evaluated for pod readiness.
+            readiness_gates (List[Any]): If specified, all readiness gates will be evaluated for pod readiness.
               A pod is ready when all its containers are ready AND all
               conditions specified in the readiness gates have status equal to
               "True" More info: https://git.k8s.io/enhancements/keps/sig-
               network/580-pod-readiness-gates
 
-            resource_claims(List[Any]): ResourceClaims defines which ResourceClaims must be allocated and
+            resource_claims (List[Any]): ResourceClaims defines which ResourceClaims must be allocated and
               reserved before the Pod is allowed to start. The resources will be
               made available to those containers which consume them by name.
               This is an alpha field and requires enabling the
               DynamicResourceAllocation feature gate.  This field is immutable.
 
-            restart_policy(str): Restart policy for all containers within the pod. One of Always,
+            restart_policy (str): Restart policy for all containers within the pod. One of Always,
               OnFailure, Never. In some contexts, only a subset of those values
               may be permitted. Default to Always. More info:
               https://kubernetes.io/docs/concepts/workloads/pods/pod-
               lifecycle/#restart-policy  Possible enum values:  - `"Always"`  -
               `"Never"`  - `"OnFailure"`
 
-            runtime_class_name(str): RuntimeClassName refers to a RuntimeClass object in the node.k8s.io
+            runtime_class_name (str): RuntimeClassName refers to a RuntimeClass object in the node.k8s.io
               group, which should be used to run this pod.  If no RuntimeClass
               resource matches the named class, the pod will not be run. If
               unset or empty, the "legacy" RuntimeClass will be used, which is
@@ -231,29 +228,29 @@ class Pod(NamespacedResource):
               runtime handler. More info:
               https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class
 
-            scheduler_name(str): If specified, the pod will be dispatched by specified scheduler. If
+            scheduler_name (str): If specified, the pod will be dispatched by specified scheduler. If
               not specified, the pod will be dispatched by default scheduler.
 
-            scheduling_gates(List[Any]): SchedulingGates is an opaque list of values that if specified will
+            scheduling_gates (List[Any]): SchedulingGates is an opaque list of values that if specified will
               block scheduling the pod. If schedulingGates is not empty, the pod
               will stay in the SchedulingGated state and the scheduler will not
               attempt to schedule the pod.  SchedulingGates can only be set at
               pod creation time, and be removed only afterwards.
 
-            security_context(Dict[str, Any]): PodSecurityContext holds pod-level security attributes and common
+            security_context (Dict[str, Any]): PodSecurityContext holds pod-level security attributes and common
               container settings. Some fields are also present in
               container.securityContext.  Field values of
               container.securityContext take precedence over field values of
               PodSecurityContext.
 
-            service_account(str): DeprecatedServiceAccount is a deprecated alias for ServiceAccountName.
+            service_account (str): DeprecatedServiceAccount is a deprecated alias for ServiceAccountName.
               Deprecated: Use serviceAccountName instead.
 
-            service_account_name(str): ServiceAccountName is the name of the ServiceAccount to use to run
+            service_account_name (str): ServiceAccountName is the name of the ServiceAccount to use to run
               this pod. More info: https://kubernetes.io/docs/tasks/configure-
               pod-container/configure-service-account/
 
-            set_hostname_as_fqdn(bool): If true the pod's hostname will be configured as the pod's FQDN,
+            set_hostname_as_fqdn (bool): If true the pod's hostname will be configured as the pod's FQDN,
               rather than the leaf name (the default). In Linux containers, this
               means setting the FQDN in the hostname field of the kernel (the
               nodename field of struct utsname). In Windows containers, this
@@ -262,18 +259,18 @@ class Pod(NamespacedResource):
               ers to FQDN. If a pod does not have FQDN, this has no effect.
               Default to false.
 
-            share_process_namespace(bool): Share a single process namespace between all of the containers in a
+            share_process_namespace (bool): Share a single process namespace between all of the containers in a
               pod. When this is set containers will be able to view and signal
               processes from other containers in the same pod, and the first
               process in each container will not be assigned PID 1. HostPID and
               ShareProcessNamespace cannot both be set. Optional: Default to
               false.
 
-            subdomain(str): If specified, the fully qualified Pod hostname will be
+            subdomain (str): If specified, the fully qualified Pod hostname will be
               "<hostname>.<subdomain>.<pod namespace>.svc.<cluster domain>". If
               not specified, the pod will not have a domainname at all.
 
-            termination_grace_period_seconds(int): Optional duration in seconds the pod needs to terminate gracefully.
+            termination_grace_period_seconds (int): Optional duration in seconds the pod needs to terminate gracefully.
               May be decreased in delete request. Value must be non-negative
               integer. The value zero indicates stop immediately via the kill
               signal (no opportunity to shut down). If this value is nil, the
@@ -283,14 +280,14 @@ class Pod(NamespacedResource):
               forcibly halted with a kill signal. Set this value longer than the
               expected cleanup time for your process. Defaults to 30 seconds.
 
-            tolerations(List[Any]): If specified, the pod's tolerations.
+            tolerations (List[Any]): If specified, the pod's tolerations.
 
-            topology_spread_constraints(List[Any]): TopologySpreadConstraints describes how a group of pods ought to
+            topology_spread_constraints (List[Any]): TopologySpreadConstraints describes how a group of pods ought to
               spread across topology domains. Scheduler will schedule pods in a
               way which abides by the constraints. All topologySpreadConstraints
               are ANDed.
 
-            volumes(List[Any]): List of volumes that can be mounted by containers belonging to the
+            volumes (List[Any]): List of volumes that can be mounted by containers belonging to the
               pod. More info:
               https://kubernetes.io/docs/concepts/storage/volumes
 
@@ -341,10 +338,8 @@ class Pod(NamespacedResource):
         super().to_dict()
 
         if not self.kind_dict and not self.yaml_file:
-            if not all([
-                self.containers,
-            ]):
-                raise MissingRequiredArgumentError(argument="containers")
+            if not self.containers:
+                raise MissingRequiredArgumentError(argument="self.containers")
 
             self.res["spec"] = {}
             _spec = self.res["spec"]
@@ -465,6 +460,8 @@ class Pod(NamespacedResource):
             if self.volumes:
                 _spec["volumes"] = self.volumes
 
+    # End of generated code
+
     def execute(self, command: List[str], timeout: int = 60, container: str = "", ignore_rc: bool = False) -> str:
         """
         Run command on Pod
