@@ -41,9 +41,9 @@ class Secret(NamespacedResource):
         self.string_data = string_data
         self.type = type
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if self.accesskeyid:
                 self.res.update({
                     "data": {
